@@ -42,14 +42,12 @@ class TagLanguageSitesFilter(object):
             return self.initial.get(field_name, None) or self.data.get(field_name, None)
 
         language = get_data("language")
-        print "TagLanguageSitesFilter language:", language
         if not language:
             # Use current language for tag queryset filter
             request = ThreadLocal.get_current_request()
             language = request.PYLUCID.current_language
 
         sites = get_data("sites")
-        print "TagLanguageSitesFilter sites:", sites
         if not sites:
             # Use current site for tag queryset filter
             sites = [settings.SITE_ID]
