@@ -92,8 +92,6 @@ class BlogForm(TagLanguageSitesFilter, forms.ModelForm):
         super(BlogForm, self).__init__(*args, **kwargs)
         self.fields["sites"].choices = Site.objects.all().values_list("id", "name")
         self.fields["sites"].initial = settings.SITE_ID
-        print "initial:", self.fields["sites"].initial
-        print "settings.SITE_ID:", settings.SITE_ID
 
     class Meta:
         model = BlogEntryContent
