@@ -6,19 +6,14 @@
 
     Register models in django admin interface.
 
-    Last commit info:
-    ~~~~~~~~~~~~~~~~~
-    $LastChangedDate$
-    $Rev$
-    $Author$
-
-    :copyleft: 2008-2010 by the PyLucid team, see AUTHORS for more details.
+    :copyleft: 2008-2012 by the PyLucid team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
 from django.contrib import admin
 
-from reversion.admin import VersionAdmin
+# https://github.com/jedie/django-reversion-compare
+from reversion_compare.admin import CompareVersionAdmin
 
 from pylucid_project.apps.pylucid.base_admin import BaseAdmin
 from pylucid_project.apps.pylucid.markup.admin import MarkupPreview
@@ -26,7 +21,7 @@ from pylucid_project.apps.pylucid.markup.admin import MarkupPreview
 from lexicon.models import LexiconEntry
 
 
-class LexiconEntryAdmin(BaseAdmin, MarkupPreview, VersionAdmin):
+class LexiconEntryAdmin(BaseAdmin, MarkupPreview, CompareVersionAdmin):
     """
     inherited attributes from BaseAdmin:
         view_on_site_link -> html link with the absolute uri.
