@@ -8,28 +8,15 @@
     Info:
         - PyLucid initial data contains english and german pages.
     
-    :copyleft: 2010-2012 by the PyLucid team, see AUTHORS for more details.
+    :copyleft: 2010-2011 by the PyLucid team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
 import os
-import sys
 
 if __name__ == "__main__":
-    # Run all unittest directly
-
-    tests = __file__
-#    tests = "pylucid_plugins.page_admin.tests.BulkEditorCsrfTest"
-#    tests = "pylucid_plugins.page_admin.tests.PageAdminTest.test_translate_form"
-
-    from pylucid_project.tests import run_test_directly
-    run_test_directly(tests,
-        verbosity=2,
-#        failfast=True,
-        failfast=False,
-    )
-    sys.exit()
-
+    # run all unittest directly
+    os.environ['DJANGO_SETTINGS_MODULE'] = "pylucid_project.settings"
 
 from django.conf import settings
 from django.test.client import Client
@@ -603,3 +590,17 @@ class BulkEditorCsrfTest(PageAdminTestCase):
             ),
         )
 
+
+
+if __name__ == "__main__":
+    # Run all unittest directly
+    from django.core import management
+
+    tests = __file__
+    tests = "pylucid_plugins.page_admin.tests.BulkEditorCsrfTest"
+#    tests = "pylucid_plugins.page_admin.tests.PageAdminTest.test_translate_form"
+
+    management.call_command('test', tests,
+        verbosity=2,
+        failfast=True
+    )
