@@ -72,12 +72,12 @@ for path in _path_list:
 DEBUG = False
 
 # Append all SQL queries into the html page. (Works only if DEBUG==True)
-# Should allways be False. It's only for developing!
+# Should allways be False. It's only for developing! 
 SQL_DEBUG = False
 
 # See if request.PYLUCID attributes attached or changes (Works only if DEBUG==True)
 # See also: http://www.pylucid.org/permalink/133/pylucid-objects#DEBUG
-# Should allways be False. It's only for developing!
+# Should allways be False. It's only for developing! 
 PYLUCID_OBJECTS_DEBUG = False
 
 # We must set a default DB settings here, otherwise management commands doesn't work.
@@ -94,6 +94,9 @@ SITE_ID = 1 # Can be changed in local_settings
 ROOT_URLCONF = 'pylucid_project.urls'
 
 
+# activate django-tools DynamicSiteMiddleware:
+USE_DYNAMIC_SITE_MIDDLEWARE = True
+
 MIDDLEWARE_CLASSES = (
     # Save process informations. More info: https://github.com/jedie/django-processinfo
     'django_processinfo.middlewares.django_processinfo.ProcessInfoMiddleware',
@@ -109,13 +112,8 @@ MIDDLEWARE_CLASSES = (
 
     # make the request object everywhere available with a thread local storage:
     'django_tools.middlewares.ThreadLocal.ThreadLocalMiddleware',
-)
 
-# activate django-tools DynamicSiteMiddleware:
-USE_DYNAMIC_SITE_MIDDLEWARE = True
-
-MIDDLEWARE_CLASSES += (
-    # Set SITE_ID dynamically base on the current domain name **Experimental** :
+    # Set SITE_ID dynamically base on the current domain name:
     'django_tools.dynamic_site.middleware.DynamicSiteMiddleware',
 
     'django.contrib.sessions.middleware.SessionMiddleware',
@@ -133,7 +131,7 @@ MIDDLEWARE_CLASSES += (
     # Create request.user_settings at process_request() and save it on process_response():
     'dbpreferences.middleware.DBPreferencesMiddleware',
 
-    # Create request.PYLUCID and log process_exception():
+    # Create request.PYLUCID and log process_exception(): 
     'pylucid_project.middlewares.pylucid_objects.PyLucidMiddleware',
 
     # slow down the django developer server
@@ -219,7 +217,7 @@ if DEBUG:
     # http://www.djangoproject.com/documentation/settings/#template-string-if-invalid
     # But note: Some django admin stuff is broken if TEMPLATE_STRING_IF_INVALID != ""
     # see also: http://code.djangoproject.com/ticket/3579
-    # A work-a-round for this lives in ./pylucid_project/apps/pylucid_admin/admin.py
+    # A work-a-round for this lives in ./pylucid_project/apps/pylucid_admin/admin.py 
     TEMPLATE_STRING_IF_INVALID = "XXX INVALID TEMPLATE STRING '%s' XXX"
 #    from django_tools.template import warn_invalid_template_vars
 #    warn_invalid_template_vars.add_warning()
@@ -242,7 +240,7 @@ INSTALLED_APPS = (
     'pylucid_project.apps.pylucid_update', # Only needed for v0.8 users
 
     # external apps shipped and used with PyLucid:
-    'django_tools.dynamic_site', # https://github.com/jedie/django-tools/blob/master/django_tools/dynamic_site/README.creole
+	'django_tools.dynamic_site', # https://github.com/jedie/django-tools/blob/master/django_tools/dynamic_site/README.creole
     'dbpreferences', # http://code.google.com/p/django-dbpreferences/
     'dbtemplates', # http://code.google.com/p/django-dbtemplates/
     'reversion', # http://code.google.com/p/django-reversion/
@@ -311,7 +309,7 @@ MEDIA_URL = None
 # https://docs.djangoproject.com/en/1.4/ref/contrib/staticfiles/#std:setting-STATICFILES_DIRS
 STATICFILES_DIRS = ()
 
-# Set base path for include plugin:
+# Set base path for include plugin: 
 # http://www.pylucid.org/permalink/381/about-the-include-plugin
 PYLUCID_INCLUDE_BASEPATH = None
 
@@ -400,7 +398,7 @@ CACHES = {
     },
 }
 
-# Set default cache timeout (in seconds) to 2 Days (used in own PyLucid cache middleware, too)
+# Set default cache timeout (in seconds) to 2 Days (used in own PyLucid cache middleware, too) 
 CACHE_MIDDLEWARE_SECONDS = 60 * 60 * 48
 
 
@@ -418,6 +416,11 @@ if _IN_UNITTESTS:
 # Must be set in local settings
 SECRET_KEY = None
 
+#_______________________________________________________________________________
+# include additional_settings from plugins
+
+PYLUCID_PLUGIN_SETUP_INFO.get_additional_settings(locals())
+
 #_______________________________________________________________________________
 # overwrite values from the local settings
 
@@ -428,7 +431,7 @@ def _error(msg):
 LOCAL_SETTINGS_MODULE = os.environ.get("LOCAL_SETTINGS_MODULE", "local_settings")
 
 try:
-    # from local_settings import *
+    # from local_settings import *    
     _local_settings = __import__(LOCAL_SETTINGS_MODULE, globals(), locals(), ["*"])
 except ImportError, err:
     if str(err).startswith("No module named"):
